from PyObjCTools import  AppHelper
import objc
objc.setVerbose(True)

import MyPDFDocument
import AppDelegate

AppHelper.runEventLoop()
